@@ -78,7 +78,7 @@ class SplitPdf(QWidget, Ui_SplitPdf):
         if self.communication:
             try:
                 #检测token是否过期的信号
-                self.communication.token_singal.emit()
+                # self.communication.token_singal.emit()
                 print("这是关闭界面的信号")
             except:
                 traceback.print_exc()
@@ -128,7 +128,8 @@ class SplitPdf(QWidget, Ui_SplitPdf):
                 self.thread1.oldPath = self.CutPdfOldPath
                 self.thread1.savePath = self.CutPdfSavaPath
                 self.thread1.filePath = self.TablePath
-            if self.communication:
+
+            if self.communication and self.thread1.filePath != "":
                 self.thread1.mainStart = 0
             self.thread1.start()
         except:
@@ -255,10 +256,13 @@ class runThread(QThread):
             traceback.print_exc()
 
     def run(self):
-        if not self.mainStart:
-            self.checkToken(7, "切分隔页")
+        # if not self.mainStart:
+        self.checkToken(7, "切分隔页")
         if self.run_code:
             self.true_run()
+        else:
+            self.communication.textSignal.emit('请登录后使用!\n')
+            self.communication.WidgetColorSignal.emit("fail")
 
     def true_run(self):
         oldPath = self.oldPath
